LinchPin 1.3.x ROADMAP - January 1, 2018???
*******************************************

Network Provisioning
----------------------------
- Teardown options

Asynchronous Target Provisioning
---------------------------------------------
- Using a distributed queue to provision targets and get their states/outputs ??? ( more research needed)

Linchpin Status tracking
--------------------------------
- Use a database to track status  multiple targets.
- Give unique identifiers to target/topology/layout triples for naming
